@@ -18,6 +18,7 @@
  *   51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA            *
  ***************************************************************************/
 #include "PovConfig.h"
+#include <cstdlib>
 
      static QString        xterm="", 
             Width="200", Height="200", 
@@ -675,7 +676,7 @@ void PovConfig::runpovray()
      "+"+SC"+Start_ColumnEdit+" "+"+EC"+End_ColumnEdit+" \
      "+Pause_When_Done+" "+"+X"+Test_Abort_CountEdit3+"\
      "+OutPutBuffer+" "+IncludeHeaderFile+" "+Continue+"  &";
-    result = system(execute_commande);
+    result = std::system(execute_commande);
    if(result != 1) std::cout << "Ok \n";
 
 };
