@@ -730,7 +730,7 @@ OpenGlWidget::OpenGlWidget( QWidget *parent, const char *name )
     VertexNumber      = 0;
 
     NBGlWindow++;
-    if(NBGlWindow == 1) {
+/*    if(NBGlWindow == 1) {
    GLfloat ambient[] = { .0, .0, .0, 1.0 };
    GLfloat diffuse[] = { 1.0, 1.0, 1.0, 1.0 };
    GLfloat lmodel_ambient[] = { 0.2, 0.2, 0.2, 1.0 };
@@ -760,7 +760,145 @@ OpenGlWidget::OpenGlWidget( QWidget *parent, const char *name )
     glTexParameterf( GL_TEXTURE_2D, GL_TEXTURE_MIN_FILTER, GL_LINEAR );
     glTexImage2D( GL_TEXTURE_2D, 0, 3, tex1.width(), tex1.height(), 0, GL_RGBA, GL_UNSIGNED_BYTE, tex1.bits() );
    // Font initialisation:
-    InitFont();
+    InitFont();*/
+}
+
+///++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++
+void OpenGlWidget::initializeGL()
+{ int i, j, k, l, mn, nbpl;
+  GLuint * PolyIndices_local_tmp;
+  GLuint * PolyIndices_localBorderCND_tmp;
+  GLuint * PolyIndices_localVerifyCND_tmp;
+  GLuint * PolyIndices_localNotVerifyCND_tmp;
+
+  boxok();
+  glInterleavedArrays (GL_N3F_V3F, 0, LocalScene.ArrayNorVer_localPt);
+
+if(LocalScene.condition == 1){
+    j = k = l = 0;
+    nbpl = (int)(NbPolygnNbVertex[0]/3);
+      //Count the number of different poly types:
+    for(i = 0; i < nbpl; i++){
+    mn = TypeIsoSurfaceTriangleListeCND[i];
+         if(mn == 1) j+=3;
+    else if(mn == 0) k+=3;
+    else if(mn == 4) l+=3;
+    }
+    // Save the result:
+    LocalScene.PolyNumberBorderCND = l;
+    LocalScene.PolyNumberVerifyCND = k;
+    LocalScene.PolyNumberNotVerifyCND = j;
+
+// No we start treating triangles: 
+PolyIndices_local_tmp = new GLuint [3*MaximumNumberTriangles];
+PolyIndices_localBorderCND_tmp = &PolyIndices_local_tmp[0];
+PolyIndices_localVerifyCND_tmp = &PolyIndices_local_tmp[l];
+PolyIndices_localNotVerifyCND_tmp = &PolyIndices_local_tmp[l+k];
+// Restart treating polygons but this time with saving them in the appropriate location:
+    j = k = l = 0;
+    for(i = 0; i < nbpl; i++){
+    mn = TypeIsoSurfaceTriangleListeCND[i];
+    if(mn == 1) {
+    PolyIndices_localNotVerifyCND_tmp[j  ] = LocalScene.PolyIndices_localPt[3*i  ];
+    PolyIndices_localNotVerifyCND_tmp[j+1] = LocalScene.PolyIndices_localPt[3*i+1];
+    PolyIndices_localNotVerifyCND_tmp[j+2] = LocalScene.PolyIndices_localPt[3*i+2];
+    j += 3;
+    }
+    else if(mn == 0) {
+    PolyIndices_localVerifyCND_tmp[k  ] = LocalScene.PolyIndices_localPt[3*i  ];
+    PolyIndices_localVerifyCND_tmp[k+1] = LocalScene.PolyIndices_localPt[3*i+1];
+    PolyIndices_localVerifyCND_tmp[k+2] = LocalScene.PolyIndices_localPt[3*i+2];
+    k += 3;
+    }
+    else if(mn == 4) {
+    PolyIndices_localBorderCND_tmp[l  ] = LocalScene.PolyIndices_localPt[3*i  ];
+    PolyIndices_localBorderCND_tmp[l+1] = LocalScene.PolyIndices_localPt[3*i+1];
+    PolyIndices_localBorderCND_tmp[l+2] = LocalScene.PolyIndices_localPt[3*i+2];
+    l += 3;
+    }
+    }
+
+memcpy(LocalScene.PolyIndices_localPt,
+       PolyIndices_local_tmp,
+       (l+k+j)*sizeof(GLuint));
+LocalScene.PolyIndices_localBorderCND = &LocalScene.PolyIndices_localPt[0];
+LocalScene.PolyIndices_localVerifyCND = &LocalScene.PolyIndices_localPt[l];
+LocalScene.PolyIndices_localNotVerifyCND = &LocalScene.PolyIndices_localPt[l+k];
+delete(PolyIndices_local_tmp);
+    }
+    InitGlParameters();
+    IndiceMorphFrame =0; /// To Initialise the morph effect
+
+}
+
+///+++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++
+void OpenGlWidget::boxok(){
+GLfloat minx= 999999999, miny= 999999999, minz= 999999999,
+        maxx=-999999999, maxy=-999999999, maxz=-999999999;
+int i, nbvertex;
+(LocalScene.typedrawing ==1) ? nbvertex = (int)NbPolygnNbVertex[0]/3 :
+                               nbvertex = (int)NbPolygnNbVertex[0]/4 ;
+nbvertex = VertexNumber;
+for(i=0; i< VertexNumber/*nbvertex*/; i++) {
+if(minx >LocalScene.ArrayNorVer_localPt[6*i+3]) minx = LocalScene.ArrayNorVer_localPt[6*i+3];
+if(miny >LocalScene.ArrayNorVer_localPt[6*i+4]) miny = LocalScene.ArrayNorVer_localPt[6*i+4];
+if(minz >LocalScene.ArrayNorVer_localPt[6*i+5]) minz = LocalScene.ArrayNorVer_localPt[6*i+5];
+
+if(maxx <LocalScene.ArrayNorVer_localPt[6*i+3]) maxx = LocalScene.ArrayNorVer_localPt[6*i+3];
+if(maxy <LocalScene.ArrayNorVer_localPt[6*i+4]) maxy = LocalScene.ArrayNorVer_localPt[6*i+4];
+if(maxz <LocalScene.ArrayNorVer_localPt[6*i+5]) maxz = LocalScene.ArrayNorVer_localPt[6*i+5];
+}
+
+LocalScene.BoxLimits[0][0] = minx;
+LocalScene.BoxLimits[1][0] = miny;
+LocalScene.BoxLimits[2][0] = minz;
+
+LocalScene.BoxLimits[0][5] = maxx;
+LocalScene.BoxLimits[1][5] = maxy;
+LocalScene.BoxLimits[2][5] = maxz;
+
+glDeleteLists(LocalScene.boxliste, 1);
+LocalScene.boxliste = glGenLists(1);
+ glNewList(LocalScene.boxliste, GL_COMPILE );
+
+  glLineWidth(2);
+   glColor3f (1., 0.0, 0.0);
+   glBegin( GL_LINES );
+glVertex3f(LocalScene.BoxLimits[0][0], LocalScene.BoxLimits[1][0], LocalScene.BoxLimits[2][0]);
+glVertex3f(LocalScene.BoxLimits[0][5], LocalScene.BoxLimits[1][0], LocalScene.BoxLimits[2][0]);
+glVertex3f(LocalScene.BoxLimits[0][5], LocalScene.BoxLimits[1][0], LocalScene.BoxLimits[2][0]);
+glVertex3f(LocalScene.BoxLimits[0][5], LocalScene.BoxLimits[1][5], LocalScene.BoxLimits[2][0]);
+glVertex3f(LocalScene.BoxLimits[0][5], LocalScene.BoxLimits[1][5], LocalScene.BoxLimits[2][0]);
+glVertex3f(LocalScene.BoxLimits[0][0], LocalScene.BoxLimits[1][5], LocalScene.BoxLimits[2][0]);
+glVertex3f(LocalScene.BoxLimits[0][0], LocalScene.BoxLimits[1][5], LocalScene.BoxLimits[2][0]);
+glVertex3f(LocalScene.BoxLimits[0][0], LocalScene.BoxLimits[1][0], LocalScene.BoxLimits[2][0]);
+
+glVertex3f(LocalScene.BoxLimits[0][0], LocalScene.BoxLimits[1][0], LocalScene.BoxLimits[2][5]);
+glVertex3f(LocalScene.BoxLimits[0][5], LocalScene.BoxLimits[1][0], LocalScene.BoxLimits[2][5]);
+glVertex3f(LocalScene.BoxLimits[0][5], LocalScene.BoxLimits[1][0], LocalScene.BoxLimits[2][5]);
+glVertex3f(LocalScene.BoxLimits[0][5], LocalScene.BoxLimits[1][5], LocalScene.BoxLimits[2][5]);
+glVertex3f(LocalScene.BoxLimits[0][5], LocalScene.BoxLimits[1][5], LocalScene.BoxLimits[2][5]);
+glVertex3f(LocalScene.BoxLimits[0][0], LocalScene.BoxLimits[1][5], LocalScene.BoxLimits[2][5]);
+glVertex3f(LocalScene.BoxLimits[0][0], LocalScene.BoxLimits[1][5], LocalScene.BoxLimits[2][5]);
+glVertex3f(LocalScene.BoxLimits[0][0], LocalScene.BoxLimits[1][0], LocalScene.BoxLimits[2][5]);
+
+glColor3f (0.0, 0.0, 1.0);
+glVertex3f(LocalScene.BoxLimits[0][0], LocalScene.BoxLimits[1][0], LocalScene.BoxLimits[2][0]);
+glVertex3f(LocalScene.BoxLimits[0][0], LocalScene.BoxLimits[1][0], LocalScene.BoxLimits[2][5]);
+
+glVertex3f(LocalScene.BoxLimits[0][5], LocalScene.BoxLimits[1][0], LocalScene.BoxLimits[2][0]);
+glVertex3f(LocalScene.BoxLimits[0][5], LocalScene.BoxLimits[1][0], LocalScene.BoxLimits[2][5]);
+
+glVertex3f(LocalScene.BoxLimits[0][5], LocalScene.BoxLimits[1][5], LocalScene.BoxLimits[2][0]);
+glVertex3f(LocalScene.BoxLimits[0][5], LocalScene.BoxLimits[1][5], LocalScene.BoxLimits[2][5]);
+
+glVertex3f(LocalScene.BoxLimits[0][0], LocalScene.BoxLimits[1][5], LocalScene.BoxLimits[2][0]);
+glVertex3f(LocalScene.BoxLimits[0][0], LocalScene.BoxLimits[1][5], LocalScene.BoxLimits[2][5]);
+   glEnd();
+
+    glLineWidth(0.9);
+   glColor3f (LocalScene.gridcol[0], LocalScene.gridcol[1], LocalScene.gridcol[3]);
+ glEndList();
 }
 
 ///+++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++
@@ -1107,73 +1245,6 @@ void OpenGlWidget::InitGlMorph() {
     InitGlParameters();
 }
 
-///++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++
-void OpenGlWidget::initializeGL()
-{ int i, j, k, l, mn, nbpl;
-  GLuint * PolyIndices_local_tmp;
-  GLuint * PolyIndices_localBorderCND_tmp;
-  GLuint * PolyIndices_localVerifyCND_tmp;
-  GLuint * PolyIndices_localNotVerifyCND_tmp;
-
-  boxok();
-  glInterleavedArrays (GL_N3F_V3F, 0, LocalScene.ArrayNorVer_localPt);
-
-if(LocalScene.condition == 1){
-    j = k = l = 0;
-    nbpl = (int)(NbPolygnNbVertex[0]/3);
-      //Count the number of different poly types:
-    for(i = 0; i < nbpl; i++){
-    mn = TypeIsoSurfaceTriangleListeCND[i];
-         if(mn == 1) j+=3;
-    else if(mn == 0) k+=3;
-    else if(mn == 4) l+=3;
-    }
-    // Save the result:
-    LocalScene.PolyNumberBorderCND = l;
-    LocalScene.PolyNumberVerifyCND = k;
-    LocalScene.PolyNumberNotVerifyCND = j;
-
-// No we start treating triangles: 
-PolyIndices_local_tmp = new GLuint [3*MaximumNumberTriangles];
-PolyIndices_localBorderCND_tmp = &PolyIndices_local_tmp[0];
-PolyIndices_localVerifyCND_tmp = &PolyIndices_local_tmp[l];
-PolyIndices_localNotVerifyCND_tmp = &PolyIndices_local_tmp[l+k];
-// Restart treating polygons but this time with saving them in the appropriate location:
-    j = k = l = 0;
-    for(i = 0; i < nbpl; i++){
-    mn = TypeIsoSurfaceTriangleListeCND[i];
-    if(mn == 1) {
-    PolyIndices_localNotVerifyCND_tmp[j  ] = LocalScene.PolyIndices_localPt[3*i  ];
-    PolyIndices_localNotVerifyCND_tmp[j+1] = LocalScene.PolyIndices_localPt[3*i+1];
-    PolyIndices_localNotVerifyCND_tmp[j+2] = LocalScene.PolyIndices_localPt[3*i+2];
-    j += 3;
-    }
-    else if(mn == 0) {
-    PolyIndices_localVerifyCND_tmp[k  ] = LocalScene.PolyIndices_localPt[3*i  ];
-    PolyIndices_localVerifyCND_tmp[k+1] = LocalScene.PolyIndices_localPt[3*i+1];
-    PolyIndices_localVerifyCND_tmp[k+2] = LocalScene.PolyIndices_localPt[3*i+2];
-    k += 3;
-    }
-    else if(mn == 4) {
-    PolyIndices_localBorderCND_tmp[l  ] = LocalScene.PolyIndices_localPt[3*i  ];
-    PolyIndices_localBorderCND_tmp[l+1] = LocalScene.PolyIndices_localPt[3*i+1];
-    PolyIndices_localBorderCND_tmp[l+2] = LocalScene.PolyIndices_localPt[3*i+2];
-    l += 3;
-    }
-    }
-
-memcpy(LocalScene.PolyIndices_localPt,
-       PolyIndices_local_tmp,
-       (l+k+j)*sizeof(GLuint));
-LocalScene.PolyIndices_localBorderCND = &LocalScene.PolyIndices_localPt[0];
-LocalScene.PolyIndices_localVerifyCND = &LocalScene.PolyIndices_localPt[l];
-LocalScene.PolyIndices_localNotVerifyCND = &LocalScene.PolyIndices_localPt[l+k];
-delete(PolyIndices_local_tmp);
-    }
-    InitGlParameters();
-    IndiceMorphFrame =0; /// To Initialise the morph effect
-
-}
 
 ///++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++
 void OpenGlWidget::scalcoeff(double ){
@@ -1530,75 +1601,6 @@ void OpenGlWidget::paintGL()
 //if(LocalScene.infos == 1)  PrintInfos2(&LocalScene);
  if(LocalScene.infos == 1)  PrintInfos();
 }
-///+++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++
-void OpenGlWidget::boxok(){
-GLfloat minx= 999999999, miny= 999999999, minz= 999999999,
-        maxx=-999999999, maxy=-999999999, maxz=-999999999;
-int i, nbvertex;
-(LocalScene.typedrawing ==1) ? nbvertex = (int)NbPolygnNbVertex[0]/3 :
-                               nbvertex = (int)NbPolygnNbVertex[0]/4 ;
-nbvertex = VertexNumber;
-for(i=0; i< VertexNumber/*nbvertex*/; i++) {
-if(minx >LocalScene.ArrayNorVer_localPt[6*i+3]) minx = LocalScene.ArrayNorVer_localPt[6*i+3];
-if(miny >LocalScene.ArrayNorVer_localPt[6*i+4]) miny = LocalScene.ArrayNorVer_localPt[6*i+4];
-if(minz >LocalScene.ArrayNorVer_localPt[6*i+5]) minz = LocalScene.ArrayNorVer_localPt[6*i+5];
-
-if(maxx <LocalScene.ArrayNorVer_localPt[6*i+3]) maxx = LocalScene.ArrayNorVer_localPt[6*i+3];
-if(maxy <LocalScene.ArrayNorVer_localPt[6*i+4]) maxy = LocalScene.ArrayNorVer_localPt[6*i+4];
-if(maxz <LocalScene.ArrayNorVer_localPt[6*i+5]) maxz = LocalScene.ArrayNorVer_localPt[6*i+5];
-}
-
-LocalScene.BoxLimits[0][0] = minx;
-LocalScene.BoxLimits[1][0] = miny;
-LocalScene.BoxLimits[2][0] = minz;
-
-LocalScene.BoxLimits[0][5] = maxx;
-LocalScene.BoxLimits[1][5] = maxy;
-LocalScene.BoxLimits[2][5] = maxz;
-
-glDeleteLists(LocalScene.boxliste, 1);
-LocalScene.boxliste = glGenLists(1);
- glNewList(LocalScene.boxliste, GL_COMPILE );
-
-  glLineWidth(2);
-   glColor3f (1., 0.0, 0.0);
-   glBegin( GL_LINES );
-glVertex3f(LocalScene.BoxLimits[0][0], LocalScene.BoxLimits[1][0], LocalScene.BoxLimits[2][0]);
-glVertex3f(LocalScene.BoxLimits[0][5], LocalScene.BoxLimits[1][0], LocalScene.BoxLimits[2][0]);
-glVertex3f(LocalScene.BoxLimits[0][5], LocalScene.BoxLimits[1][0], LocalScene.BoxLimits[2][0]);
-glVertex3f(LocalScene.BoxLimits[0][5], LocalScene.BoxLimits[1][5], LocalScene.BoxLimits[2][0]);
-glVertex3f(LocalScene.BoxLimits[0][5], LocalScene.BoxLimits[1][5], LocalScene.BoxLimits[2][0]);
-glVertex3f(LocalScene.BoxLimits[0][0], LocalScene.BoxLimits[1][5], LocalScene.BoxLimits[2][0]);
-glVertex3f(LocalScene.BoxLimits[0][0], LocalScene.BoxLimits[1][5], LocalScene.BoxLimits[2][0]);
-glVertex3f(LocalScene.BoxLimits[0][0], LocalScene.BoxLimits[1][0], LocalScene.BoxLimits[2][0]);
-
-glVertex3f(LocalScene.BoxLimits[0][0], LocalScene.BoxLimits[1][0], LocalScene.BoxLimits[2][5]);
-glVertex3f(LocalScene.BoxLimits[0][5], LocalScene.BoxLimits[1][0], LocalScene.BoxLimits[2][5]);
-glVertex3f(LocalScene.BoxLimits[0][5], LocalScene.BoxLimits[1][0], LocalScene.BoxLimits[2][5]);
-glVertex3f(LocalScene.BoxLimits[0][5], LocalScene.BoxLimits[1][5], LocalScene.BoxLimits[2][5]);
-glVertex3f(LocalScene.BoxLimits[0][5], LocalScene.BoxLimits[1][5], LocalScene.BoxLimits[2][5]);
-glVertex3f(LocalScene.BoxLimits[0][0], LocalScene.BoxLimits[1][5], LocalScene.BoxLimits[2][5]);
-glVertex3f(LocalScene.BoxLimits[0][0], LocalScene.BoxLimits[1][5], LocalScene.BoxLimits[2][5]);
-glVertex3f(LocalScene.BoxLimits[0][0], LocalScene.BoxLimits[1][0], LocalScene.BoxLimits[2][5]);
-
-glColor3f (0.0, 0.0, 1.0);
-glVertex3f(LocalScene.BoxLimits[0][0], LocalScene.BoxLimits[1][0], LocalScene.BoxLimits[2][0]);
-glVertex3f(LocalScene.BoxLimits[0][0], LocalScene.BoxLimits[1][0], LocalScene.BoxLimits[2][5]);
-
-glVertex3f(LocalScene.BoxLimits[0][5], LocalScene.BoxLimits[1][0], LocalScene.BoxLimits[2][0]);
-glVertex3f(LocalScene.BoxLimits[0][5], LocalScene.BoxLimits[1][0], LocalScene.BoxLimits[2][5]);
-
-glVertex3f(LocalScene.BoxLimits[0][5], LocalScene.BoxLimits[1][5], LocalScene.BoxLimits[2][0]);
-glVertex3f(LocalScene.BoxLimits[0][5], LocalScene.BoxLimits[1][5], LocalScene.BoxLimits[2][5]);
-
-glVertex3f(LocalScene.BoxLimits[0][0], LocalScene.BoxLimits[1][5], LocalScene.BoxLimits[2][0]);
-glVertex3f(LocalScene.BoxLimits[0][0], LocalScene.BoxLimits[1][5], LocalScene.BoxLimits[2][5]);
-   glEnd();
-
-    glLineWidth(0.9);
-   glColor3f (LocalScene.gridcol[0], LocalScene.gridcol[1], LocalScene.gridcol[3]);
- glEndList();
-}
 
 ///+++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++
 void OpenGlWidget::mouseReleaseEvent( QMouseEvent *){
