@@ -128,7 +128,7 @@ struct  Scene {
 
 
 class OpenGlWidget : public QGLWidget, public QThread
-{    Q_OBJECT
+{
 public :
     static int TransparenceVal;
     int colortype, btgauche, btdroit, btmilieu,
